@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: gravfft.c 12427 2013-11-01 17:03:18Z jluis $
+ *	$Id: gravfft.c 12822 2014-01-31 23:39:56Z remko $
  *
- *	Copyright (c) 1991-2013 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2014 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -136,7 +136,7 @@ void *New_gravfft_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new
 	
 	/* Initialize values whose defaults are not 0/false/NULL */
 
-	C->E.n_terms = 1;
+	C->E.n_terms = 3;
 	return (C);
 }
 
@@ -167,7 +167,7 @@ int GMT_gravfft_parse (struct GMT_CTRL *GMT, struct GRAVFFT_CTRL *Ctrl, struct G
 
 	unsigned int n_errors = 0;
 
-	int n, override_mode = GMT_FFT_REMOVE_MEAN;
+	int n, override_mode = GMT_FFT_REMOVE_MID;
 	struct GMT_OPTION *opt = NULL,  *popt = NULL;
 	struct GMTAPI_CTRL *API = GMT->parent;
 	char   ptr[GMT_BUFSIZ] = {""}, t_or_b[4] = {""}, argument[GMT_LEN16] = {""}, combined[GMT_BUFSIZ] = {""};
@@ -227,7 +227,7 @@ int GMT_gravfft_parse (struct GMT_CTRL *GMT, struct GRAVFFT_CTRL *Ctrl, struct G
 				}
 				Ctrl->D.active = true;
 				Ctrl->misc.rho = atof (opt->arg);
-				override_mode = GMT_FFT_REMOVE_MEAN;	/* Leave trend alone and remove mean */
+				override_mode = GMT_FFT_REMOVE_MID;		/* Leave trend alone and remove mid value */
 				break;
 			case 'E':
 				Ctrl->E.n_terms = atoi (opt->arg);
@@ -297,7 +297,7 @@ int GMT_gravfft_parse (struct GMT_CTRL *GMT, struct GRAVFFT_CTRL *Ctrl, struct G
 				break;
 			case 'Q':
 				Ctrl->Q.active = true;
-				override_mode = GMT_FFT_REMOVE_MEAN;	/* Leave trend alone and remove mean */
+				override_mode = GMT_FFT_REMOVE_MID;	/* Leave trend alone and remove mid value */
 				break;
 			case 'S':
 				Ctrl->S.active = true;
@@ -309,12 +309,11 @@ int GMT_gravfft_parse (struct GMT_CTRL *GMT, struct GRAVFFT_CTRL *Ctrl, struct G
 				Ctrl->T.rho_mc = Ctrl->T.rhom - Ctrl->T.rhol;
 				Ctrl->T.rho_mw = Ctrl->T.rhom - Ctrl->T.rhow;
 				if (Ctrl->T.te > 1e10) { /* Given flexural rigidity, compute Te */
-					Ctrl->T.te = pow ((12.0 * (1.0 - POISSONS_RATIO * POISSONS_RATIO)) * Ctrl->T.te
-					     / YOUNGS_MODULUS, 1./3.);
+					Ctrl->T.te = pow ((12.0 * (1.0 - POISSONS_RATIO * POISSONS_RATIO)) * Ctrl->T.te / YOUNGS_MODULUS, 1./3.);
 				}
 				if (opt->arg[strlen(opt->arg)-2] == '+') {	/* Fragile. Needs further testing */
 					Ctrl->T.moho = true;
-					override_mode = GMT_FFT_REMOVE_MEAN;	/* Leave trend alone and remove mean */
+					override_mode = GMT_FFT_REMOVE_MID;		/* Leave trend alone and remove mid value */
 				}
 				break;
 			case 'Z':
@@ -336,9 +335,10 @@ int GMT_gravfft_parse (struct GMT_CTRL *GMT, struct GRAVFFT_CTRL *Ctrl, struct G
 			else
 				Ctrl->N.info->trend_mode = override_mode;
 		}
-		if (!n_errors && Ctrl->N.info->trend_mode == 0)		/* No explict detrending mode, so apply default */
+		if (!n_errors && Ctrl->N.info->trend_mode == GMT_FFT_REMOVE_NOT_SET)		/* No explict detrending mode, so apply default */
 			Ctrl->N.info->trend_mode = override_mode;
 	}
+
 	if (Ctrl->N.active && Ctrl->N.info->info_mode == GMT_FFT_LIST) {
 		return (GMT_PARSE_ERROR);	/* So that we exit the program */
 	}
@@ -416,7 +416,7 @@ int GMT_gravfft_usage (struct GMTAPI_CTRL *API, int level) {
 	GMT_Message (API, GMT_TIME_NONE,"\t       theoretical admittance.\n");
 	GMT_Message (API, GMT_TIME_NONE,"\t     t writes a forth column with \"elastic plate\" \n");
 	GMT_Message (API, GMT_TIME_NONE,"\t       theoretical admittance.\n");
-	GMT_Message (API, GMT_TIME_NONE,"\t-E number of terms used in Parker's expansion [Default = 1].\n");
+	GMT_Message (API, GMT_TIME_NONE,"\t-E number of terms used in Parker's expansion [Default = 3].\n");
 	GMT_Message (API, GMT_TIME_NONE,"\t-F Specify desired geopotential field:\n");
 	GMT_Message (API, GMT_TIME_NONE,"\t   f = Free-air anomalies (mGal) [Default].\n");
 	GMT_Message (API, GMT_TIME_NONE,"\t   g = Geoid anomalies (m).\n");
@@ -494,7 +494,7 @@ int GMT_gravfft (void *V_API, int mode, void *args) {
 		delta_pt = 2 * M_PI / (Ctrl->C.n_pt * Ctrl->C.theor_inc);	/* Times 2PI because frequency will be used later */
 		compute_only_admitts (GMT, Ctrl, K, z_top_or_bot, delta_pt);
 		sprintf (format, "%s%s%s\n", GMT->current.setting.format_float_out, 
-				GMT->current.setting.io_col_separator, GMT->current.setting.format_float_out);
+                 GMT->current.setting.io_col_separator, GMT->current.setting.format_float_out);
 		delta_pt /= (2.0 * M_PI);			/* Write out frequency, not wavenumber  */
 		if (Ctrl->misc.give_wavelength && Ctrl->misc.give_km) delta_pt *= 1000.0;	/* Wanted wavelength in km */
 
@@ -511,11 +511,13 @@ int GMT_gravfft (void *V_API, int mode, void *args) {
 	}
 	/* ---------------------------------------------------------------------------------- */
 
-	if (((Ctrl->T.active && !Ctrl->T.moho) && Ctrl->E.n_terms > 1) || (Ctrl->S.active && Ctrl->E.n_terms > 1)) {
-		GMT_Report (API, GMT_MSG_NORMAL, "Warning: Due to a bug, or a method limitation (I didn't figure that yet)\n"
-			"with the selected options, the number of terms in Parker expansion is reset to one\n"
-			"See examples in the manual if you want to compute with higher order expansion\n\n"); 
-		Ctrl->E.n_terms = 1;
+	if (!Ctrl->Q.active) {
+		if (((Ctrl->T.active && !Ctrl->T.moho) && Ctrl->E.n_terms > 1) || (Ctrl->S.active && Ctrl->E.n_terms > 1)) {
+			GMT_Report (API, GMT_MSG_NORMAL, "Warning: Due to a bug, or a method limitation (I didn't figure that yet)\n"
+				"with the selected options, the number of terms in Parker expansion is reset to one\n"
+				"See examples in the manual if you want to compute with higher order expansion\n\n"); 
+			Ctrl->E.n_terms = 1;
+		}
 	}
 
 	GMT_Report (API, GMT_MSG_VERBOSE, "Allocates memory and read data file\n");
@@ -548,7 +550,8 @@ int GMT_gravfft (void *V_API, int mode, void *args) {
 	
 	for (k = 0; k < Ctrl->In.n_grids; k++) {	/* Read, and check that no NaNs are present in either grid */
 		GMT_grd_init (GMT, Orig[k]->header, options, true);	/* Update the header */
-		if ((Orig[k] = GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_DATA_ONLY | GMT_GRID_IS_COMPLEX_REAL, NULL, Ctrl->In.file[k], Orig[k])) == NULL)        /* Get data only */
+		if ((Orig[k] = GMT_Read_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_DATA_ONLY |
+                                      GMT_GRID_IS_COMPLEX_REAL, NULL, Ctrl->In.file[k], Orig[k])) == NULL)	/* Get data only */
 			Return (API->error);
 		/* Note: If input grid(s) are read-only then we must duplicate them; otherwise Grid[k] points to Orig[k] */
 		(void) GMT_set_outgrid (GMT, Ctrl->In.file[k], Orig[k], &Grid[k]);
@@ -564,11 +567,11 @@ int GMT_gravfft (void *V_API, int mode, void *args) {
 					Grid[0]->data[GMT_IJP(Grid[0]->header,j,i)] += (float)Ctrl->A.z_offset;
 		}
 
-		FFT_info[k] = GMT_FFT_Create (API, Grid[k], GMT_FFT_DIM, GMT_GRID_IS_COMPLEX_REAL, Ctrl->N.info);
+		FFT_info[k] = GMT_FFT_Create (API, Grid[k], GMT_FFT_DIM, GMT_GRID_IS_COMPLEX_REAL, Ctrl->N.info);	/* Also detrends, if requested */
 	}
-	
+
 	K = FFT_info[0];	/* We only need one of these anyway; K is a shorthand */
-	
+
 	Ctrl->misc.z_level = fabs (FFT_info[0]->coeff[0]);	/* Need absolute value or level removed for uppward continuation */
 
 	if (Ctrl->I.active) {		/* Compute admittance or coherence from data and exit */
@@ -606,13 +609,19 @@ int GMT_gravfft (void *V_API, int mode, void *args) {
 			GMT_scale_and_offset_f (GMT, Grid[0]->data, Grid[0]->header->size, scale_out, 0);
 
 		if (!Ctrl->T.moho) {
-			GMT_grd_detrend (GMT, Grid[0], Ctrl->N.info->trend_mode, coeff);
-			Ctrl->misc.z_level = fabs (coeff[0]);	/* Need absolute value or level removed for uppward continuation */
-    			GMT_scale_and_offset_f (GMT, Grid[0]->data, Grid[0]->header->size, 1.0, -Ctrl->Z.zm);
+
+			if (false && Ctrl->N.info->trend_mode != GMT_FFT_REMOVE_MEAN) { /* Account also for the difference between detrend level and true mean  */
+				GMT_grd_detrend (GMT, Grid[0], GMT_FFT_REMOVE_MEAN, coeff);
+				GMT_scale_and_offset_f (GMT, Grid[0]->data, Grid[0]->header->size, 1.0, -Ctrl->Z.zm);
+			}
+			else
+				GMT_scale_and_offset_f (GMT, Grid[0]->data, Grid[0]->header->size, 1.0, -Ctrl->Z.zm);
 
 			/* The data are in the middle of the padded array; only the interior (original dimensions) will be written to file */
-			if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_OPTION | GMT_COMMENT_IS_COMMAND, options, Grid[0])) Return (API->error);
-			if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_DATA_ONLY | GMT_GRID_IS_COMPLEX_REAL, NULL, Ctrl->G.file, Grid[0]) != GMT_OK) {
+			if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_OPTION | GMT_COMMENT_IS_COMMAND, options, Grid[0]))
+				Return (API->error);
+			if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_DATA_ONLY |
+                                GMT_GRID_IS_COMPLEX_REAL, NULL, Ctrl->G.file, Grid[0]) != GMT_OK) {
 				Return (API->error);
 			}
 			GMT_free (GMT, K);
@@ -694,7 +703,8 @@ int GMT_gravfft (void *V_API, int mode, void *args) {
 	GMT_free (GMT, raised);
 
 	if (GMT_Set_Comment (API, GMT_IS_GRID, GMT_COMMENT_IS_OPTION | GMT_COMMENT_IS_COMMAND, options, Grid[0])) Return (API->error);
-	if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_DATA_ONLY | GMT_GRID_IS_COMPLEX_REAL, NULL, Ctrl->G.file, Grid[0]) != GMT_OK) {
+	if (GMT_Write_Data (API, GMT_IS_GRID, GMT_IS_FILE, GMT_IS_SURFACE, GMT_GRID_DATA_ONLY |
+                        GMT_GRID_IS_COMPLEX_REAL, NULL, Ctrl->G.file, Grid[0]) != GMT_OK) {
 		Return (API->error);
 	}
 
