@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: psimage.c 12407 2013-10-30 16:46:27Z pwessel $
+ *	$Id: psimage.c 12822 2014-01-31 23:39:56Z remko $
  *
- *	Copyright (c) 1991-2013 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2014 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -34,41 +34,40 @@
 #define GMT_PROG_OPTIONS "->JKOPRUVXYcptxy"
 
 struct PSIMAGE_CTRL {
-	struct In {
+	struct PSIMG_In {
 		bool active;
 		char *file;
 	} In;
-	struct C {	/* -C<xpos>/<ypos>[/<justify>] */
+	struct PSIMG_C {	/* -C<xpos>/<ypos>[/<justify>] */
 		bool active;
 		double x, y;
 		char justify[3];
 	} C;
-	struct E {	/* -E<dpi> */
+	struct PSIMG_E {	/* -E<dpi> */
 		bool active;
 		double dpi;
 	} E;
-	struct F {	/* -F<pen> */
+	struct PSIMG_F {	/* -F<pen> */
 		bool active;
 		struct GMT_PEN pen;
 	} F;
-	struct G {	/* -G[f|b|t]<rgb> */
+	struct PSIMG_G {	/* -G[f|b|t]<rgb> */
 		bool active;
-		unsigned int mode;	/* 0 for f|b, 1 for t */
 		double f_rgb[4];
 		double b_rgb[4];
 		double t_rgb[4];
 	} G;
-	struct I {	/* -I */
+	struct PSIMG_I {	/* -I */
 		bool active;
 	} I;
-	struct M {	/* -M */
+	struct PSIMG_M {	/* -M */
 		bool active;
 	} M;
-	struct N {	/* -N<nx>/<ny> */
+	struct PSIMG_N {	/* -N<nx>/<ny> */
 		bool active;
 		unsigned int nx, ny;
 	} N;
-	struct W {	/* -W[-]<width>[/<height>] */
+	struct PSIMG_W {	/* -W[-]<width>[/<height>] */
 		bool active;
 		bool interpolate;
 		double width, height;
@@ -77,14 +76,14 @@ struct PSIMAGE_CTRL {
 
 void *New_psimage_Ctrl (struct GMT_CTRL *GMT) {	/* Allocate and initialize a new control structure */
 	struct PSIMAGE_CTRL *C;
-	
+
 	C = GMT_memory (GMT, NULL, 1, struct PSIMAGE_CTRL);
-	
+
 	/* Initialize values whose defaults are not 0/false/NULL */
 	C->F.pen = GMT->current.setting.map_default_pen;
 	strcpy (C->C.justify, "LB");
 	C->G.f_rgb[0] = C->G.b_rgb[0] = C->G.t_rgb[0] = -2;
-	C->N.nx = C->N.ny = 1;	
+	C->N.nx = C->N.ny = 1;
 	return (C);
 }
 
@@ -127,7 +126,7 @@ int GMT_psimage_usage (struct GMTAPI_CTRL *API, int level)
 	GMT_Option (API, "O,P,R,U,V,X,c,p");
 	GMT_Message (API, GMT_TIME_NONE, "\t   (Requires -R and -J for proper functioning).\n");
 	GMT_Option (API, "t,.");
-	
+
 	return (EXIT_FAILURE);
 }
 
@@ -179,7 +178,7 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 				break;
 			case 'G':	/* Background/foreground color for 1-bit images */
 				Ctrl->G.active = true;
-				letter = (GMT_colorname2index (GMT, opt->arg) >= 0) ? 'x' : opt->arg[0];	/* If we have -G<colorname>, the x is used to bypass the case F|f|B|b switching below */
+				letter = (GMT_colorname2index (GMT, opt->arg) >= 0) ? 'x' : opt->arg[0];	/* If we have -G<colorname>, the x is used to bypass the case f|b|t switching below */
 				switch (letter) {
 					case 'f':
 						/* Set color for foreground pixels */
@@ -205,7 +204,6 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 							GMT_rgb_syntax (GMT, 'G', " ");
 							n_errors++;
 						}
-						Ctrl->G.mode = 1;
 						break;
 					default:	/* Gave either -G<r/g/b>, -G-, or -G<colorname>; all treated as -Gf */
 						if (opt->arg[0] == '-' && opt->arg[1] == '\0')
@@ -255,9 +253,9 @@ int GMT_psimage_parse (struct GMT_CTRL *GMT, struct PSIMAGE_CTRL *Ctrl, struct G
 
 	n_errors += GMT_check_condition (GMT, n_files != 1, "Syntax error: Must specify a single input raster or EPS file\n");
 	n_errors += GMT_check_condition (GMT, Ctrl->W.width <= 0.0 && Ctrl->E.dpi <= 0.0, "Must specify image width (-W) or dpi (-E)\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->N.active && (Ctrl->N.nx < 1 || Ctrl->N.ny < 1), 
+	n_errors += GMT_check_condition (GMT, Ctrl->N.active && (Ctrl->N.nx < 1 || Ctrl->N.ny < 1),
 			"Syntax error -N option: Must specify positive values for replication\n");
-	n_errors += GMT_check_condition (GMT, Ctrl->G.f_rgb[0] < 0 && Ctrl->G.b_rgb[0] < 0, 
+	n_errors += GMT_check_condition (GMT, Ctrl->G.f_rgb[0] < 0 && Ctrl->G.b_rgb[0] < 0,
 			"Syntax error -G option: Only one of fore/back-ground can be transparent for 1-bit images\n");
 
 	return (n_errors ? GMT_PARSE_ERROR : GMT_OK);
@@ -290,18 +288,61 @@ int file_is_known (struct GMT_CTRL *GMT, char *file)
 	return (0);	/* Neither */
 }
 
+#define Return(code) {GMT_free (GMT, table); return (code);}
+
+int find_unique_color (struct GMT_CTRL *GMT, unsigned char *rgba, size_t n, int *r, int *g, int *b)
+{
+	size_t i, j;
+	int idx;
+	bool trans = false;
+	unsigned char *table = NULL;
+
+	table = GMT_memory (GMT, NULL, 256*256*256, unsigned char);	/* Get table all initialized to zero */
+
+	/* Check off all the non-transparent colors, store the transparent one */
+	*r = *g = *b = 0;
+	for (i = j = 0; i < n; i++, j+=4) {
+		if (rgba[j+3] == 0)
+			*r = rgba[j], *g = rgba[j+1], *b = rgba[j+2], trans = true;
+		else {
+			idx = 256 * (256*(int)rgba[j] + (int)rgba[j+1]) + (int)rgba[j+2];
+			table[idx] = true;
+		}
+	}
+
+	/* Was there a transparent color? */
+	if (!trans) Return (0);
+
+	/* Was the transparent color unique? */
+	idx = 256 * (256*(*r) + (*g)) + (*b);
+	if (!table[idx]) Return (1);
+
+	/* Find a unique color */
+	idx = 0;
+	for (*r = 0; *r < 256; (*r)++) {
+		for (*g = 0; *g < 256; (*g)++) {
+			for (*b = 0; *b < 256; (*b)++, idx++) {
+				if (!table[idx]) Return (2);
+			}
+		}
+	}
+	Return (3);
+}
+#undef Return
+
 #define bailout(code) {GMT_Free_Options (mode); return (code);}
 #define Return(code) {Free_psimage_Ctrl (GMT, Ctrl); GMT_end_module (GMT, GMT_cpy); bailout (code);}
 
 int GMT_psimage (void *V_API, int mode, void *args)
 {
-	int i, j, n, justify, PS_interpolate = 1, PS_transparent = 1, known = 0, error = 0;
+	int i, j, k, n, justify, PS_interpolate = 1, PS_transparent = 1, known = 0, error = 0, has_trans = 0;
 	unsigned int row, col;
 	bool free_GMT = false, did_gray = false;
 
 	double x, y, wesn[4];
 
-	unsigned char *picture = NULL, *buffer = NULL;
+	unsigned char *picture = NULL, *buffer = NULL, colormap[4*256];
+	int r, g, b;
 
 	char *format[2] = {"EPS", "Sun raster"};
 
@@ -358,31 +399,47 @@ int GMT_psimage (void *V_API, int mode, void *args)
 		}
 		GMT_set_pad (GMT, API->pad);	/* Reset to GMT default */
 
-		if (I->ColorMap != NULL) {
-			unsigned char *r_table = NULL, *g_table = NULL, *b_table = NULL;
-			r_table = GMT_memory (GMT, NULL, 256, unsigned char);
-			g_table = GMT_memory (GMT, NULL, 256, unsigned char);
-			b_table = GMT_memory (GMT, NULL, 256, unsigned char);
-			for (n = 0; n < 256; n++) {
-				r_table[n] = I->ColorMap[n*4    ];	/* 4 because color table is RGBA */
-				g_table[n] = I->ColorMap[n*4 + 1];
-				b_table[n] = I->ColorMap[n*4 + 2];
-			}
-			I->data = GMT_memory (GMT, I->data, 3 * I->header->nm, unsigned char);	/* Expand to reuse */
+		/* Handle transparent images */
+		if (I->ColorMap != NULL) {	/* Image has a color map */
+			/* Convert colormap from integer to unsigned char and count colors */
+			for (n = 0; n < 4 * 256 && I->ColorMap[n] >= 0; n++) colormap[n] = (unsigned char)I->ColorMap[n];
+			n /= 4;
+			if (!Ctrl->G.active) has_trans = find_unique_color (GMT, colormap, n, &r, &g, &b);
+
+			/* Expand 8-bit indexed image to 24-bit image */
+			I->data = GMT_memory (GMT, I->data, 3 * I->header->nm, unsigned char);
 			n = (int)(3 * I->header->nm - 1);
 			for (j = (int)I->header->nm - 1; j >= 0; j--) {
-				I->data[n--] = b_table[I->data[j]];
-				I->data[n--] = g_table[I->data[j]];
-				I->data[n--] = r_table[I->data[j]];	/* Now we can overwrite this value */
+				k = 4 * I->data[j] + 3;
+				if (has_trans && colormap[k] == 0)
+					I->data[n--] = b, I->data[n--] = g, I->data[n--] = r;
+				else
+					I->data[n--] = colormap[--k], I->data[n--] = colormap[--k], I->data[n--] = colormap[--k];
 			}
 			I->header->n_bands = 3;
-			GMT_free (GMT, r_table);	GMT_free (GMT, g_table);	GMT_free (GMT, b_table);
+		}
+		else if (I->header->n_bands == 4) { /* RGBA image, with a color map */
+			if (!Ctrl->G.active) has_trans = find_unique_color (GMT, I->data, I->header->nm, &r, &g, &b);
+			for (j = n = 0; j < 4 * (int)I->header->nm; j++) { /* Reduce image from 32- to 24-bit */
+				if (has_trans && I->data[j+3] == 0)
+					I->data[n++] = r, I->data[n++] = g, I->data[n++] = b, j+=3;
+				else
+					I->data[n++] = I->data[j++], I->data[n++] = I->data[j++], I->data[n++] = I->data[j++];
+			}
+			I->header->n_bands = 3;
+		}
+
+		/* If a transparent color was found, we replace it with a unique one */
+		if (has_trans) {
+			Ctrl->G.t_rgb[0] = r / 255.;
+			Ctrl->G.t_rgb[1] = g / 255.;
+			Ctrl->G.t_rgb[2] = b / 255.;
 		}
 
 		picture = (unsigned char *)I->data;
 		header.width = I->header->nx;
 		header.height = I->header->ny;
-		header.depth = (int)(I->header->n_bands * 8);
+		header.depth = (int)I->header->n_bands * 8;
 	}
 #else
 	else {	/* Without GDAL we can only read EPS and Sun raster */
@@ -390,7 +447,7 @@ int GMT_psimage (void *V_API, int mode, void *args)
 		Return (EXIT_FAILURE);
 	}
 #endif
-	
+
 	if (Ctrl->M.active && header.depth == 24) {	/* Downgrade to grayshade image */
 		did_gray = true;
 		n = 3 * header.width * header.height;
@@ -415,8 +472,8 @@ int GMT_psimage (void *V_API, int mode, void *args)
 		j = header.depth / 8;
 		n = j * (header.width * header.height + 1);
 		buffer = GMT_memory (GMT, NULL, n, unsigned char);
-		for (i = 0; i < j; i++) buffer[i] = (unsigned char)Ctrl->G.t_rgb[i];
-		GMT_memcpy (&(buffer[j]), picture, n, unsigned char);
+		for (i = 0; i < j; i++) buffer[i] = (unsigned char)rint(255 * Ctrl->G.t_rgb[i]);
+		GMT_memcpy (&(buffer[j]), picture, n - j, unsigned char);
 #ifdef HAVE_GDAL
 		if (GMT_Destroy_Data (API, &I) != GMT_OK) {	/* If I is NULL then nothing is done */
 			Return (API->error);
@@ -465,19 +522,19 @@ int GMT_psimage (void *V_API, int mode, void *args)
 		for (col = 0; col < Ctrl->N.nx; col++) {
 			x = Ctrl->C.x + col * Ctrl->W.width;
 			if (header.depth == 0)
-				PSL_plotepsimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture, header.length, 
+				PSL_plotepsimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture, header.length,
 						header.width, header.height, header.xorigin, header.yorigin);
 			else if (header.depth == 1) {
 				/* Invert is opposite from what is expected. This is to match the behaviour of -Gp */
 				if (Ctrl->I.active)
-					PSL_plotbitimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture, 
+					PSL_plotbitimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture,
 							header.width, header.height, Ctrl->G.f_rgb, Ctrl->G.b_rgb);
 				else
-					PSL_plotbitimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture, 
+					PSL_plotbitimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture,
 							header.width, header.height, Ctrl->G.b_rgb, Ctrl->G.f_rgb);
 			}
 			else
-				 PSL_plotcolorimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture, 
+				 PSL_plotcolorimage (PSL, x, y, Ctrl->W.width, Ctrl->W.height, PSL_BL, picture,
 						 PS_transparent * header.width, header.height, PS_interpolate * header.depth);
 		}
 	}
