@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: spectrum1d.c 12407 2013-10-30 16:46:27Z pwessel $
+ *	$Id: spectrum1d.c 12822 2014-01-31 23:39:56Z remko $
  *
- *	Copyright (c) 1991-2013 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
+ *	Copyright (c) 1991-2014 by P. Wessel, W. H. F. Smith, R. Scharroo, J. Luis and F. Wobbe
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -716,7 +716,7 @@ int GMT_spectrum1d (void *V_API, int mode, void *args)
 	}
 	for (tbl = 0; tbl < Din->n_tables; tbl++) {
 		if (one_table) {
-			GMT_free_table (GMT, Dout->table[tbl]);	/* Free it, then allocate separately */
+			GMT_free_table (GMT, Dout->table[tbl], Dout->alloc_mode);	/* Free it, then allocate separately */
 			Dout->table[tbl] = Tout = GMT_create_table (GMT, Din->table[tbl]->n_segments, C.n_spec, 3, false);
 		}
 		for (seg = 0; seg < Din->table[tbl]->n_segments; seg++) {
